# -*- coding: utf-8 -*-
# Copyright (C) 2022 mhertz <yourname@example.com>
#
# Basic plugin template created by the Deluge Team.
#
# This file is part of whitelist and is licensed under GNU GPL 3.0, or later,
# with the additional special exception to link portions of this program with
# the OpenSSL library. See LICENSE for more details.
from __future__ import unicode_literals

import logging

from deluge.plugins.pluginbase import CorePluginBase
import deluge.component as component
import deluge.common
from deluge._libtorrent import LT_VERSION, lt
from urllib.request import urlopen

log = logging.getLogger(__name__)

class Core(CorePluginBase):
    def enable(self):
        try:
            version = urlopen('http://download.deluge-torrent.org/version-2.0').read().decode().strip()
        except Exception:
            version = '2.0.5'
        split = deluge.common.VersionSplit(version)
        version_list = split.version + [0] * (4 - len(split.version))
        peer_id = lt.generate_fingerprint('DE', *version_list)
        peer_id = peer_id[:6] + 's' + peer_id[6 + 1 :]
        session = component.get("Core").session
        session.apply_settings({'peer_fingerprint': peer_id, 'user_agent': f'Deluge/{peer_id} libtorrent/{LT_VERSION}'})

    def disable(self):
        version = deluge.common.get_version()
        split = deluge.common.VersionSplit(version)
        version_list = split.version + [0] * (4 - len(split.version))
        peer_id = lt.generate_fingerprint('DE', *version_list)

        def substitute_chr(string, idx, char):
            return string[:idx] + char + string[idx + 1 :]

        if split.dev:
            release_chr = 'D'
        elif split.suffix:
            release_chr = split.suffix[0].lower()
        else:
            release_chr = 's'
        peer_id = substitute_chr(peer_id, 6, release_chr)
        session = component.get("Core").session
        session.apply_settings({'peer_fingerprint': peer_id, 'user_agent': f'Deluge/{peer_id} libtorrent/{LT_VERSION}'})

    def update(self):
        pass
